py_convert_to_snake_case

Function py_convert_to_snake_case 

pub fn py_convert_to_snake_case(input: &str) -> String
Convert the given string from any common case (PascalCase, camelCase, kebab-case, etc.) to lower snake_case.

This function uses the heck Rust crate under the hood.

Parameters

input : str The input string to convert.

Returns

str